############
Installation
############


********
Overview
********

This document provides the instruction to build the HexWatershed model.

************
Requirements
************



***********
Instruction 
***********

pip install pyflowline

- By now, your build should be successful if you receive no errors. And you will see the binary file in the CMake folder and another one within the repository as well.



Congratulations, you have successfully built the HexWatershed model!


